==> hvcg_iam_openapi_identity-0.0.2.crate: hvcg_iam_openapi_identity-0.0.2/docs/mutation_user_api.md <==
# mutation_user_api

All URIs are relative to *https://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**activate_user**](mutation_user_api.md#activate_user) | **POST** /mutation-api/identity-service/users/activation | Activate a user
**create-user**](mutation_user_api.md#create-user) | **POST** /mutation-api/identity-service/user | Create user
**deactivate_user**](mutation_user_api.md#deactivate_user) | **POST** /mutation-api/identity-service/users/deactivation | Deactive user
**update-password**](mutation_user_api.md#update-password) | **PUT** /mutation-api/identity-service/users/password | update password


# **activate_user**
> models::User activate_user(ctx, )
Activate a user

Activate user

### Required Parameters
This endpoint does not need any parameter.

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create-user**
> models::User create-user(ctx, user)
Create user

Create user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **user** | [**User**](User.md)| User object that needs to be added to the database | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deactivate_user**
> models::User deactivate_user(ctx, )
Deactive user

Deactivate user

### Required Parameters
This endpoint does not need any parameter.

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update-password**
> models::User update-password(ctx, inline_object)
update password

Update user password

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object** | [**InlineObject**](InlineObject.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> hvcg_iam_openapi_identity-0.0.4.crate: hvcg_iam_openapi_identity-0.0.4/docs/mutation_user_api.md <==
# mutation_user_api

All URIs are relative to *https://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**activate_user**](mutation_user_api.md#activate_user) | **POST** /mutation-api/identity-service/users/activation | Activate a user
**create-user**](mutation_user_api.md#create-user) | **POST** /mutation-api/identity-service/users | Create user
**deactivate_user**](mutation_user_api.md#deactivate_user) | **POST** /mutation-api/identity-service/users/deactivation | Deactive user
**update-password**](mutation_user_api.md#update-password) | **PUT** /mutation-api/identity-service/users/password | update password


# **activate_user**
> models::User activate_user(ctx, inline_object2)
Activate a user

Activate user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object2** | [**InlineObject2**](InlineObject2.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create-user**
> models::User create-user(ctx, user)
Create user

Create user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **user** | [**User**](User.md)| User object that needs to be added to the database | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deactivate_user**
> models::User deactivate_user(ctx, inline_object1)
Deactive user

Deactivate user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object1** | [**InlineObject1**](InlineObject1.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update-password**
> models::User update-password(ctx, inline_object)
update password

Update user password

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object** | [**InlineObject**](InlineObject.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
